pub enum Error {
Parse(ParseError),
ExcessParam(String),
UnknownDirective(String),
MissingValue(String),
Cardinality(String),
FromStr(String),
DuplicateKey(String),
}Expand description
Errors that can occur while parsing or transforming scfg documents.
Variants
Parse(ParseError)
A syntax error encountered while parsing the scfg document.
ExcessParam(String)
A directive had more parameters than expected.
UnknownDirective(String)
A document had an unknown directive.
MissingValue(String)
An expected item was not found.
Cardinality(String)
The number of values found did not match the expectations.
FromStr(String)
An error occurred converting the input string to the desired type.
DuplicateKey(String)
A duplicate key occurred converting the input string to a map type.